Title: [132363] trunk/Source/WebKit/gtk
Revision
132363
Author
[email protected]
Date
2012-10-24 09:43:55 -0700 (Wed, 24 Oct 2012)

Log Message

[GTK] Typos in user-visible strings: "coordintate"
https://bugs.webkit.org/show_bug.cgi?id=100252

Patch by Priit Laes <[email protected]> on 2012-10-24
Reviewed by Martin Robinson.

s/coordintate/coordinate

* webkit/webkithittestresult.cpp:
(webkit_hit_test_result_class_init):

Modified Paths

Diff

Modified: trunk/Source/WebKit/gtk/ChangeLog (132362 => 132363)


--- trunk/Source/WebKit/gtk/ChangeLog	2012-10-24 16:23:22 UTC (rev 132362)
+++ trunk/Source/WebKit/gtk/ChangeLog	2012-10-24 16:43:55 UTC (rev 132363)
@@ -1,3 +1,15 @@
+2012-10-24  Priit Laes  <[email protected]>
+
+        [GTK] Typos in user-visible strings: "coordintate"
+        https://bugs.webkit.org/show_bug.cgi?id=100252
+
+        Reviewed by Martin Robinson.
+
+        s/coordintate/coordinate
+
+        * webkit/webkithittestresult.cpp:
+        (webkit_hit_test_result_class_init):
+
 2012-10-23  Martin Robinson  <[email protected]>
 
         [GTK][Soup] Implement the default authentication dialog via WebCoreSupport

Modified: trunk/Source/WebKit/gtk/webkit/webkithittestresult.cpp (132362 => 132363)


--- trunk/Source/WebKit/gtk/webkit/webkithittestresult.cpp	2012-10-24 16:23:22 UTC (rev 132362)
+++ trunk/Source/WebKit/gtk/webkit/webkithittestresult.cpp	2012-10-24 16:43:55 UTC (rev 132363)
@@ -245,28 +245,28 @@
     /**
      * WebKitHitTestResult:x:
      *
      * The x coordintate of the event relative to the view's window.
      *
      * Since: 1.10
      */
     g_object_class_install_property(objectClass, PROP_X,
                                     g_param_spec_int("x",
                                                      _("X coordinate"),
-                                                     _("The x coordintate of the event relative to the view's window."),
+                                                     _("The x coordinate of the event relative to the view's window."),
                                                      G_MININT, G_MAXINT, 0,
                                                      static_cast<GParamFlags>(WEBKIT_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY)));
 
     /**
      * WebKitHitTestResult:y:
      *
      * The x coordintate of the event relative to the view's window.
      *
      * Since: 1.10
      */
     g_object_class_install_property(objectClass, PROP_Y,
                                     g_param_spec_int("y",
                                                      _("Y coordinate"),
-                                                     _("The y coordintate of the event relative to the view's window."),
+                                                     _("The y coordinate of the event relative to the view's window."),
                                                      G_MININT, G_MAXINT, 0,
                                                      static_cast<GParamFlags>(WEBKIT_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY)));
 
@@ -245,28 +245,28 @@
      * WebKitHitTestResult:x:
      *
-     * The x coordintate of the event relative to the view's window.
+     * The x coordinate of the event relative to the view's window.
      *
      * Since: 1.10
@@ -245,28 +245,28 @@
      * WebKitHitTestResult:y:
      *
-     * The x coordintate of the event relative to the view's window.
+     * The x coordinate of the event relative to the view's window.
      *
      * Since: 1.10
_______________________________________________
webkit-changes mailing list
[email protected]
http://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to